Exception

Struct Exception 

pub struct Exception<'exc, 'data> { /* private fields */ }
A caught exception

Implementations

Source

impl<'exc, 'data> Exception<'exc, 'data>

pub fn value(self) -> Value<'exc, 'data>

Get the current exception as a Value.

pub unsafe fn rethrow(self)

Rethrow the current exception.

Safety: this new exception causes execution to jump to the next enclosing try-catch block, no pending drops may be jumped over.

pub unsafe fn rethrow_other(self, exc: Value<'_, '_>)

Rethrow another value as the current exception.

Safety: this new exception causes execution to jump to the next enclosing try-catch block, no pending drops may be jumped over.

pub fn print_backtrace(self)

Prints the current exception and the backtrace to stderr.