NdArrayViewMut

Trait NdArrayViewMut 

pub trait NdArrayViewMut<'view, T>: NdArrayView<'view, T> {
    // Required methods
    fn array_view_mut(&'view mut self) -> ArrayViewMut<'view, T, IxDyn>;
    fn compatible_array_view_mut<U>(
        &'view mut self,
    ) -> ArrayViewMut<'view, U, IxDyn>
       where T: Compatible<U>;
}
Trait to borrow Julia arrays with inline data as ndarray’s ArrayViewMut.

Required Methods

fn array_view_mut(&'view mut self) -> ArrayViewMut<'view, T, IxDyn>

Mutably borrow the data in the array as an ArrayViewMut.

fn compatible_array_view_mut<U>( &'view mut self, ) -> ArrayViewMut<'view, U, IxDyn>
where T: Compatible<U>,

Mutably borrow the data in the array as an ArrayViewMut of a compatible type U.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'borrow: 'view, 'view, 'array, 'data, T, L, const N: isize> NdArrayViewMut<'view, L> for BitsAccessorMut<'borrow, 'array, 'data, T, L, N>
where L: ValidField + IsBits,

Source

impl<'view, T> NdArrayViewMut<'view, T> for CopiedArray<T>