#[repr(C)]pub struct Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>(pub T1, pub T2, pub T3, pub T4, pub T5, pub T6, pub T7, pub T8, pub T9, pub T10, pub T11, pub T12, pub T13, pub T14, pub T15);Tuple Fields
0: T11: T22: T33: T44: T55: T66: T77: T88: T99: T1010: T1111: T1212: T1313: T1414: T15Trait Implementations
Sourceimpl<T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone, T6: Clone, T7: Clone, T8: Clone, T9: Clone, T10: Clone, T11: Clone, T12: Clone, T13: Clone, T14: Clone, T15: Clone> Clone for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
impl<T1: Clone, T2: Clone, T3: Clone, T4: Clone, T5: Clone, T6: Clone, T7: Clone, T8: Clone, T9: Clone, T10: Clone, T11: Clone, T12: Clone, T13: Clone, T14: Clone, T15: Clone> Clone for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ConstructType for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ConstructType,
T2: ConstructType,
T3: ConstructType,
T4: ConstructType,
T5: ConstructType,
T6: ConstructType,
T7: ConstructType,
T8: ConstructType,
T9: ConstructType,
T10: ConstructType,
T11: ConstructType,
T12: ConstructType,
T13: ConstructType,
T14: ConstructType,
T15: ConstructType,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ConstructType for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ConstructType,
T2: ConstructType,
T3: ConstructType,
T4: ConstructType,
T5: ConstructType,
T6: ConstructType,
T7: ConstructType,
T8: ConstructType,
T9: ConstructType,
T10: ConstructType,
T11: ConstructType,
T12: ConstructType,
T13: ConstructType,
T14: ConstructType,
T15: ConstructType,
Sourcetype Static = Tuple15<<T1 as ConstructType>::Static, <T2 as ConstructType>::Static, <T3 as ConstructType>::Static, <T4 as ConstructType>::Static, <T5 as ConstructType>::Static, <T6 as ConstructType>::Static, <T7 as ConstructType>::Static, <T8 as ConstructType>::Static, <T9 as ConstructType>::Static, <T10 as ConstructType>::Static, <T11 as ConstructType>::Static, <T12 as ConstructType>::Static, <T13 as ConstructType>::Static, <T14 as ConstructType>::Static, <T15 as ConstructType>::Static>
type Static = Tuple15<<T1 as ConstructType>::Static, <T2 as ConstructType>::Static, <T3 as ConstructType>::Static, <T4 as ConstructType>::Static, <T5 as ConstructType>::Static, <T6 as ConstructType>::Static, <T7 as ConstructType>::Static, <T8 as ConstructType>::Static, <T9 as ConstructType>::Static, <T10 as ConstructType>::Static, <T11 as ConstructType>::Static, <T12 as ConstructType>::Static, <T13 as ConstructType>::Static, <T14 as ConstructType>::Static, <T15 as ConstructType>::Static>
Self, but with all lifetimes set to 'static. This ensures Self::Static has a type
id.Sourcefn construct_type_uncached<'target, Tgt>(
target: Tgt,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_uncached<'target, Tgt>(
target: Tgt,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Constructs the type object associated with this type.
Sourcefn construct_type_with_env_uncached<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_with_env_uncached<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Constructs the type object associated with this type. Read more
Sourcefn base_type<'target, Tgt>(target: &Tgt) -> Option<Value<'target, 'static>>where
Tgt: Target<'target>,
fn base_type<'target, Tgt>(target: &Tgt) -> Option<Value<'target, 'static>>where
Tgt: Target<'target>,
Returns the base type object associated with this type. Read more
Sourcefn construct_type<'target, Tgt>(target: Tgt) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type<'target, Tgt>(target: Tgt) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Construct the type object and try to cache the result. If a cached entry is available, it
is returned.
Sourcefn construct_type_with_env<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_with_env<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Construct the type object with an environment of
TypeVars and try to cache the result.
If a cached entry is available, it is returned. Read moreimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Copy for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: IntoJulia + Debug + Copy,
T2: IntoJulia + Debug + Copy,
T3: IntoJulia + Debug + Copy,
T4: IntoJulia + Debug + Copy,
T5: IntoJulia + Debug + Copy,
T6: IntoJulia + Debug + Copy,
T7: IntoJulia + Debug + Copy,
T8: IntoJulia + Debug + Copy,
T9: IntoJulia + Debug + Copy,
T10: IntoJulia + Debug + Copy,
T11: IntoJulia + Debug + Copy,
T12: IntoJulia + Debug + Copy,
T13: IntoJulia + Debug + Copy,
T14: IntoJulia + Debug + Copy,
T15: IntoJulia + Debug + Copy,
Sourceimpl<T1: Debug, T2: Debug, T3: Debug, T4: Debug, T5: Debug, T6: Debug, T7: Debug, T8: Debug, T9: Debug, T10: Debug, T11: Debug, T12: Debug, T13: Debug, T14: Debug, T15: Debug> Debug for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
impl<T1: Debug, T2: Debug, T3: Debug, T4: Debug, T5: Debug, T6: Debug, T7: Debug, T8: Debug, T9: Debug, T10: Debug, T11: Debug, T12: Debug, T13: Debug, T14: Debug, T15: Debug> Debug for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
impl<T1: Eq, T2: Eq, T3: Eq, T4: Eq, T5: Eq, T6: Eq, T7: Eq, T8: Eq, T9: Eq, T10: Eq, T11: Eq, T12: Eq, T13: Eq, T14: Eq, T15: Eq> Eq for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoJulia for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: IntoJulia + ConstructType + Debug + Clone,
T2: IntoJulia + ConstructType + Debug + Clone,
T3: IntoJulia + ConstructType + Debug + Clone,
T4: IntoJulia + ConstructType + Debug + Clone,
T5: IntoJulia + ConstructType + Debug + Clone,
T6: IntoJulia + ConstructType + Debug + Clone,
T7: IntoJulia + ConstructType + Debug + Clone,
T8: IntoJulia + ConstructType + Debug + Clone,
T9: IntoJulia + ConstructType + Debug + Clone,
T10: IntoJulia + ConstructType + Debug + Clone,
T11: IntoJulia + ConstructType + Debug + Clone,
T12: IntoJulia + ConstructType + Debug + Clone,
T13: IntoJulia + ConstructType + Debug + Clone,
T14: IntoJulia + ConstructType + Debug + Clone,
T15: IntoJulia + ConstructType + Debug + Clone,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IntoJulia for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: IntoJulia + ConstructType + Debug + Clone,
T2: IntoJulia + ConstructType + Debug + Clone,
T3: IntoJulia + ConstructType + Debug + Clone,
T4: IntoJulia + ConstructType + Debug + Clone,
T5: IntoJulia + ConstructType + Debug + Clone,
T6: IntoJulia + ConstructType + Debug + Clone,
T7: IntoJulia + ConstructType + Debug + Clone,
T8: IntoJulia + ConstructType + Debug + Clone,
T9: IntoJulia + ConstructType + Debug + Clone,
T10: IntoJulia + ConstructType + Debug + Clone,
T11: IntoJulia + ConstructType + Debug + Clone,
T12: IntoJulia + ConstructType + Debug + Clone,
T13: IntoJulia + ConstructType + Debug + Clone,
T14: IntoJulia + ConstructType + Debug + Clone,
T15: IntoJulia + ConstructType + Debug + Clone,
Sourcefn julia_type<'scope, Tgt>(target: Tgt) -> DataTypeData<'scope, Tgt>where
Tgt: Target<'scope>,
fn julia_type<'scope, Tgt>(target: Tgt) -> DataTypeData<'scope, Tgt>where
Tgt: Target<'scope>,
Returns the associated Julia type of the implementor. Read more
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> IsBits for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: Clone + Debug + IsBits + ValidField,
T2: Clone + Debug + IsBits + ValidField,
T3: Clone + Debug + IsBits + ValidField,
T4: Clone + Debug + IsBits + ValidField,
T5: Clone + Debug + IsBits + ValidField,
T6: Clone + Debug + IsBits + ValidField,
T7: Clone + Debug + IsBits + ValidField,
T8: Clone + Debug + IsBits + ValidField,
T9: Clone + Debug + IsBits + ValidField,
T10: Clone + Debug + IsBits + ValidField,
T11: Clone + Debug + IsBits + ValidField,
T12: Clone + Debug + IsBits + ValidField,
T13: Clone + Debug + IsBits + ValidField,
T14: Clone + Debug + IsBits + ValidField,
T15: Clone + Debug + IsBits + ValidField,
Sourceimpl<T1: PartialEq, T2: PartialEq, T3: PartialEq, T4: PartialEq, T5: PartialEq, T6: PartialEq, T7: PartialEq, T8: PartialEq, T9: PartialEq, T10: PartialEq, T11: PartialEq, T12: PartialEq, T13: PartialEq, T14: PartialEq, T15: PartialEq> PartialEq for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
impl<T1: PartialEq, T2: PartialEq, T3: PartialEq, T4: PartialEq, T5: PartialEq, T6: PartialEq, T7: PartialEq, T8: PartialEq, T9: PartialEq, T10: PartialEq, T11: PartialEq, T12: PartialEq, T13: PartialEq, T14: PartialEq, T15: PartialEq> PartialEq for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
impl<T1: PartialEq, T2: PartialEq, T3: PartialEq, T4: PartialEq, T5: PartialEq, T6: PartialEq, T7: PartialEq, T8: PartialEq, T9: PartialEq, T10: PartialEq, T11: PartialEq, T12: PartialEq, T13: PartialEq, T14: PartialEq, T15: PartialEq> StructuralPartialEq for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Typecheck for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Typecheck for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Unbox for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> Unbox for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ValidField for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ValidField for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
Sourcefn valid_field(v: Value<'_, '_>) -> bool
fn valid_field(v: Value<'_, '_>) -> bool
Returns
true if Self is the correct representation for Julia data of type ty
when it’s used as a field type.Sourceimpl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ValidLayout for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,
impl<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> ValidLayout for Tuple15<T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
T4: ValidField + Clone + Debug,
T5: ValidField + Clone + Debug,
T6: ValidField + Clone + Debug,
T7: ValidField + Clone + Debug,
T8: ValidField + Clone + Debug,
T9: ValidField + Clone + Debug,
T10: ValidField + Clone + Debug,
T11: ValidField + Clone + Debug,
T12: ValidField + Clone + Debug,
T13: ValidField + Clone + Debug,
T14: ValidField + Clone + Debug,
T15: ValidField + Clone + Debug,