#[repr(C)]pub struct Tuple3<T1, T2, T3>(pub T1, pub T2, pub T3);Tuple Fields
0: T11: T22: T3Trait Implementations
Sourceimpl<T1, T2, T3> ConstructType for Tuple3<T1, T2, T3>
impl<T1, T2, T3> ConstructType for Tuple3<T1, T2, T3>
Sourcetype Static = Tuple3<<T1 as ConstructType>::Static, <T2 as ConstructType>::Static, <T3 as ConstructType>::Static>
type Static = Tuple3<<T1 as ConstructType>::Static, <T2 as ConstructType>::Static, <T3 as ConstructType>::Static>
Self, but with all lifetimes set to 'static. This ensures Self::Static has a type
id.Sourcefn construct_type_uncached<'target, Tgt>(
target: Tgt,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_uncached<'target, Tgt>(
target: Tgt,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Constructs the type object associated with this type.
Sourcefn construct_type_with_env_uncached<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_with_env_uncached<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Constructs the type object associated with this type. Read more
Sourcefn base_type<'target, Tgt>(target: &Tgt) -> Option<Value<'target, 'static>>where
Tgt: Target<'target>,
fn base_type<'target, Tgt>(target: &Tgt) -> Option<Value<'target, 'static>>where
Tgt: Target<'target>,
Returns the base type object associated with this type. Read more
Sourcefn construct_type<'target, Tgt>(target: Tgt) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type<'target, Tgt>(target: Tgt) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Construct the type object and try to cache the result. If a cached entry is available, it
is returned.
Sourcefn construct_type_with_env<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
fn construct_type_with_env<'target, Tgt>(
target: Tgt,
env: &TypeVarEnv<'_>,
) -> ValueData<'target, 'static, Tgt>where
Tgt: Target<'target>,
Construct the type object with an environment of
TypeVars and try to cache the result.
If a cached entry is available, it is returned. Read moreimpl<T1, T2, T3> Copy for Tuple3<T1, T2, T3>
impl<T1: Eq, T2: Eq, T3: Eq> Eq for Tuple3<T1, T2, T3>
Sourceimpl<T1, T2, T3> IntoJulia for Tuple3<T1, T2, T3>where
T1: IntoJulia + ConstructType + Debug + Clone,
T2: IntoJulia + ConstructType + Debug + Clone,
T3: IntoJulia + ConstructType + Debug + Clone,
impl<T1, T2, T3> IntoJulia for Tuple3<T1, T2, T3>where
T1: IntoJulia + ConstructType + Debug + Clone,
T2: IntoJulia + ConstructType + Debug + Clone,
T3: IntoJulia + ConstructType + Debug + Clone,
Sourcefn julia_type<'scope, Tgt>(target: Tgt) -> DataTypeData<'scope, Tgt>where
Tgt: Target<'scope>,
fn julia_type<'scope, Tgt>(target: Tgt) -> DataTypeData<'scope, Tgt>where
Tgt: Target<'scope>,
Returns the associated Julia type of the implementor. Read more
impl<T1, T2, T3> IsBits for Tuple3<T1, T2, T3>where
T1: Clone + Debug + IsBits + ValidField,
T2: Clone + Debug + IsBits + ValidField,
T3: Clone + Debug + IsBits + ValidField,
impl<T1: PartialEq, T2: PartialEq, T3: PartialEq> StructuralPartialEq for Tuple3<T1, T2, T3>
Sourceimpl<T1, T2, T3> Typecheck for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
impl<T1, T2, T3> Typecheck for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
Sourceimpl<T1, T2, T3> Unbox for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
impl<T1, T2, T3> Unbox for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
Sourceimpl<T1, T2, T3> ValidField for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
impl<T1, T2, T3> ValidField for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
Sourcefn valid_field(v: Value<'_, '_>) -> bool
fn valid_field(v: Value<'_, '_>) -> bool
Returns
true if Self is the correct representation for Julia data of type ty
when it’s used as a field type.Sourceimpl<T1, T2, T3> ValidLayout for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,
impl<T1, T2, T3> ValidLayout for Tuple3<T1, T2, T3>where
T1: ValidField + Clone + Debug,
T2: ValidField + Clone + Debug,
T3: ValidField + Clone + Debug,