pub type RankedArrayRet<const N: isize> = WeakRankedArray<'static, 'static, N>;Aliased Type
pub struct RankedArrayRet<const N: isize>(/* private fields */);Trait Implementations
Sourceimpl<const N: isize> CCallReturn for RankedArrayRet<N>
impl<const N: isize> CCallReturn for RankedArrayRet<N>
Sourcetype CCallReturnType = AnyType
type CCallReturnType = AnyType
Type constructor for the type returned by the
ccalled function.Sourcetype FunctionReturnType = ArrayBase<'static, 'static, Unknown, N>
type FunctionReturnType = ArrayBase<'static, 'static, Unknown, N>
Type constructor for the type returned by the generated Julia function.
Sourcetype ReturnAs = Weak<'static, 'static, ArrayBase<'static, 'static, Unknown, N>>
type ReturnAs = Weak<'static, 'static, ArrayBase<'static, 'static, Unknown, N>>
Type returned to Julia after calling
Self::return_or_throw.Sourceunsafe fn return_or_throw(self) -> Self::ReturnAs
unsafe fn return_or_throw(self) -> Self::ReturnAs
Convert
self to data that can be returned to Julia, or throw an exception. Read more