SimpleVector

Struct SimpleVector 

pub struct SimpleVector<'scope>(/* private fields */);
A SimpleVector is a fixed-size array that contains WeakValues.

Implementations

Source

impl<'scope> SimpleVector<'scope>

pub fn new<'elem, Tgt, T>( target: Tgt, elems: &[T], ) -> SimpleVectorData<'scope, Tgt>
where Tgt: Target<'scope>, T: Managed<'elem, 'static>,

Create a new SimpleVector that contains every element in elems.

pub fn with_capacity<Tgt>( target: Tgt, n: usize, ) -> SimpleVectorData<'scope, Tgt>
where Tgt: Target<'scope>,

Create a new SimpleVector that can hold n values.

pub unsafe fn with_capacity_uninit<Tgt>( target: Tgt, n: usize, ) -> SimpleVectorData<'scope, Tgt>
where Tgt: Target<'scope>,

Create a new SimpleVector that can hold n values without initializing its contents.

Safety: The contents must be set before calling Julia again, the contents must never be accessed before all elements are set.

pub fn copy<'target, Tgt>(self, target: Tgt) -> SimpleVectorData<'target, Tgt>
where Tgt: Target<'target>,

Copy an existing SimpleVector.

pub fn data<'borrow>(&'borrow self) -> SimpleVectorAccessor<'borrow>

Immutably access the contents of this SimpleVector.

pub unsafe fn typed_data_unchecked<'borrow, U>( &'borrow self, ) -> SimpleVectorAccessor<'borrow, U>
where U: Managed<'borrow, 'static>,

Access the contents of this SimpleVector as U.

Safety: this method doesn’t check if U is correct for all elements.

pub fn len(&self) -> usize

Returns the length of this SimpleVector.

Source

impl<'base> SimpleVector<'base>

pub fn emptysvec<Tgt: Target<'base>>(_: &Tgt) -> Self

The empty SimpleVector.