Weak

Struct Weak 

pub struct Weak<'scope, 'data, T: ManagedPriv<'scope, 'data>>(/* private fields */);
A reference to Julia data that is not guaranteed to be rooted.

Managed types are generally guaranteed to wrap valid, rooted data. In some cases this guarantee is too strong. The garbage collector uses the roots as a starting point to determine what values can be reached, as long as you can guarantee a value is reachable it’s safe to use. Whenever data is not rooted jlrs returns a Weak. Because it’s not rooted it’s unsafe to use.

Implementations

Source

impl<'scope, 'data> Weak<'scope, 'data, TypedValue<'scope, 'data, AnyType>>

pub fn from_value_ref(value_ref: WeakValue<'scope, 'data>) -> Self

Source

impl<'scope, 'data, W: Managed<'scope, 'data>> Weak<'scope, 'data, W>

pub unsafe fn root<'target, Tgt>( self, target: Tgt, ) -> Tgt::Data<'data, W::InScope<'target>>
where Tgt: Target<'target>,

Use target to root self.

Safety: The data pointed to by self must not have been freed by the GC yet.

pub unsafe fn as_managed(self) -> W

Assume the reference still points to valid managed data and convert it to its managed type.

Safety: a reference is only guaranteed to be valid as long as it’s reachable from some GC root. If the reference is unreachable, the GC can free it. The GC can run whenever a safepoint is reached, this is typically the case when new Julia data is allocated.

pub unsafe fn as_value(self) -> Value<'scope, 'data>

Assume the reference still points to valid managed data and convert it to a Value.

Safety: a reference is only guaranteed to be valid as long as it’s reachable from some GC root. If the reference is unreachable, the GC can free it. The GC can run whenever a safepoint is reached, this is typically the case when new Julia data is allocated.

pub unsafe fn assume_owned(self) -> Weak<'scope, 'static, W::WithData<'static>>

Extends the 'data lifetime to 'static.

Safety: this method should only be used when no data borrowed from Rust is referenced by this Julia data.

pub fn leak(self) -> Weak<'static, 'data, W::InScope<'static>>

Extends the 'scope lifetime to 'static, which allows this reference to Julia data to be leaked from a scope.

Safety: this method should only be called to return Julia data from a ccalled function or when storing Julia data in a foreign type.

pub fn data_ptr(self) -> NonNull<c_void>

Returns a pointer to the data.