StaticGlobal

Struct StaticGlobal 

pub struct StaticGlobal<T> { /* private fields */ }
Static reference to arbitrary managed data. Guaranteed to be initialized at most once.

Implementations

Source

impl<T> StaticGlobal<T>
where T: Managed<'static, 'static> + Typecheck,

pub const fn new(path: &'static str) -> StaticGlobal<T>

Define a new static global available at path.

The global is looked up only once when this data is accessedd for the first time. The path argument must be the full path to the data, e.g. "Main.Submodule.Foo".

pub fn get_or_init<'target, Tgt>(&self, target: &Tgt) -> T
where Tgt: Target<'target>,

Get the global data, look it up if it doesn’t exist yet.

The global must exist and be an instance of T. Otherwise this method will panic.

Source

impl StaticGlobal<ValueUnbound>

pub const fn new_value(path: &'static str) -> StaticGlobal<ValueUnbound>

Define a new static global available at path.

The global is looked up only once when this data is accessedd for the first time. The path argument must be the full path to the data, e.g. "Main.Submodule.Foo".