pub struct Exception<'exc, 'data> { /* private fields */ }Expand description
A caught exception
Implementations
Sourceimpl<'exc, 'data> Exception<'exc, 'data>
impl<'exc, 'data> Exception<'exc, 'data>
Sourcepub unsafe fn rethrow(self)
pub unsafe fn rethrow(self)
Rethrow the current exception.
Safety: this new exception causes execution to jump to the next enclosing try-catch block, no pending drops may be jumped over.
Sourcepub unsafe fn rethrow_other(self, exc: Value<'_, '_>)
pub unsafe fn rethrow_other(self, exc: Value<'_, '_>)
Rethrow another value as the current exception.
Safety: this new exception causes execution to jump to the next enclosing try-catch block, no pending drops may be jumped over.
Sourcepub fn print_backtrace(self)
pub fn print_backtrace(self)
Prints the current exception and the backtrace to stderr.