pub struct SimpleVector<'scope>(/* private fields */);Expand description
A SimpleVector is a fixed-size array that contains WeakValues.
Implementations
Sourceimpl<'scope> SimpleVector<'scope>
impl<'scope> SimpleVector<'scope>
Sourcepub fn new<'elem, Tgt, T>(
target: Tgt,
elems: &[T],
) -> SimpleVectorData<'scope, Tgt>
pub fn new<'elem, Tgt, T>( target: Tgt, elems: &[T], ) -> SimpleVectorData<'scope, Tgt>
Create a new SimpleVector that contains every element in elems.
Sourcepub fn with_capacity<Tgt>(
target: Tgt,
n: usize,
) -> SimpleVectorData<'scope, Tgt>where
Tgt: Target<'scope>,
pub fn with_capacity<Tgt>(
target: Tgt,
n: usize,
) -> SimpleVectorData<'scope, Tgt>where
Tgt: Target<'scope>,
Create a new SimpleVector that can hold n values.
Sourcepub unsafe fn with_capacity_uninit<Tgt>(
target: Tgt,
n: usize,
) -> SimpleVectorData<'scope, Tgt>where
Tgt: Target<'scope>,
pub unsafe fn with_capacity_uninit<Tgt>(
target: Tgt,
n: usize,
) -> SimpleVectorData<'scope, Tgt>where
Tgt: Target<'scope>,
Create a new SimpleVector that can hold n values without initializing its contents.
Safety: The contents must be set before calling Julia again, the contents must never be accessed before all elements are set.
Sourcepub fn copy<'target, Tgt>(self, target: Tgt) -> SimpleVectorData<'target, Tgt>where
Tgt: Target<'target>,
pub fn copy<'target, Tgt>(self, target: Tgt) -> SimpleVectorData<'target, Tgt>where
Tgt: Target<'target>,
Copy an existing SimpleVector.
Sourcepub fn data<'borrow>(&'borrow self) -> SimpleVectorAccessor<'borrow>
pub fn data<'borrow>(&'borrow self) -> SimpleVectorAccessor<'borrow>
Immutably access the contents of this SimpleVector.
Sourcepub unsafe fn typed_data_unchecked<'borrow, U>(
&'borrow self,
) -> SimpleVectorAccessor<'borrow, U>where
U: Managed<'borrow, 'static>,
pub unsafe fn typed_data_unchecked<'borrow, U>(
&'borrow self,
) -> SimpleVectorAccessor<'borrow, U>where
U: Managed<'borrow, 'static>,
Access the contents of this SimpleVector as U.
Safety: this method doesn’t check if U is correct for all elements.